pub enum EmbeddedThemeName {
Show 32 variants
Ansi,
Base16,
Base16EightiesDark,
Base16MochaDark,
Base16OceanDark,
Base16OceanLight,
Base16_256,
CatppuccinFrappe,
CatppuccinLatte,
CatppuccinMacchiato,
CatppuccinMocha,
ColdarkCold,
ColdarkDark,
DarkNeon,
Dracula,
Github,
GruvboxDark,
GruvboxLight,
InspiredGithub,
Leet,
MonokaiExtended,
MonokaiExtendedBright,
MonokaiExtendedLight,
MonokaiExtendedOrigin,
Nord,
OneHalfDark,
OneHalfLight,
SolarizedDark,
SolarizedLight,
SublimeSnazzy,
TwoDark,
Zenburn,
}Expand description
An enum that represents all themes included in EmbeddedLazyThemeSet
A demo is included for how each theme highlights the following Julia snippet adapted from the Julia Getting Started manual
# sends a variety of values over a channel
function producer(c::Channel)
for n=1:4
put!(c, 2n)
end
put!(c, "stop")
end;Variants
Ansi
ANSI
Doesn’t display as HTML well
Base16
Base16
Doesn’t display as HTML well
Base16EightiesDark
Base16 Eighties Dark
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Base16MochaDark
Base16 Mocha Dark Theme
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Base16OceanDark
Base16 Ocean Dark
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Base16OceanLight
Base16 Ocean Light
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Base16_256
Base16 256
Doesn’t display as HTML well
CatppuccinFrappe
Catppuccin Frappe
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
CatppuccinLatte
Catppuccin Latte
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
CatppuccinMacchiato
Catppuccin Macchiato
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
CatppuccinMocha
Catppuccin Mocha
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
ColdarkCold
Coldark-Cold
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
ColdarkDark
Coldark-Dark
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
DarkNeon
Dark Neon
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Dracula
Dracula
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Github
GitHub
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
GruvboxDark
gruvbox (Dark)
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
GruvboxLight
gruvbox (Light)
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
InspiredGithub
Inspired GitHub
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Leet
1337
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
MonokaiExtended
Monokai Extended
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
MonokaiExtendedBright
Monokai Extended Bright
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
MonokaiExtendedLight
Monokai Extended Light
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
MonokaiExtendedOrigin
Monokai Extended Origin
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Nord
Nord
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
OneHalfDark
One Half Dark
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
OneHalfLight
One Half Light
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
SolarizedDark
Solarized (dark)
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
SolarizedLight
Solarized (light)
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
SublimeSnazzy
Sublime Snazzy
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
TwoDark
TwoDark
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Zenburn
zenburn
# sends a variety of values over a channel function producer(c::Channel) for n=1:4 put!(c, 2n) end put!(c, "stop") end;
Implementations
Sourceimpl EmbeddedThemeName
impl EmbeddedThemeName
Sourcepub fn as_name(self) -> &'static str
pub fn as_name(self) -> &'static str
The name of each embedded theme
This matches the key used for each theme in ThemeSet’s themes
use two_face::theme::EmbeddedThemeName;
assert_eq!(
EmbeddedThemeName::Leet.as_name(),
"1337",
);
// `.as_name()` is used for `Display` too!
assert_eq!(
EmbeddedThemeName::SolarizedDark.to_string(),
"Solarized (dark)",
);Trait Implementations
Sourceimpl Clone for EmbeddedThemeName
impl Clone for EmbeddedThemeName
Sourcefn clone(&self) -> EmbeddedThemeName
fn clone(&self) -> EmbeddedThemeName
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Copy for EmbeddedThemeName
Sourceimpl Debug for EmbeddedThemeName
impl Debug for EmbeddedThemeName
Sourceimpl Display for EmbeddedThemeName
impl Display for EmbeddedThemeName
impl Eq for EmbeddedThemeName
Sourceimpl Hash for EmbeddedThemeName
impl Hash for EmbeddedThemeName
Sourceimpl Ord for EmbeddedThemeName
impl Ord for EmbeddedThemeName
Sourcefn cmp(&self, other: &EmbeddedThemeName) -> Ordering
fn cmp(&self, other: &EmbeddedThemeName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for EmbeddedThemeName
impl PartialEq for EmbeddedThemeName
Sourceimpl PartialOrd for EmbeddedThemeName
impl PartialOrd for EmbeddedThemeName
impl StructuralPartialEq for EmbeddedThemeName